<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        xmlns:xs="http://www.w3.org/2001/XMLSchema"
        xmlns:str="http://mathdoc.fr/string-function-namespace"
        exclude-result-prefixes="str xs">

    <xsl:template name="copy">
        <xsl:param name="subject" select="." />
        <xsl:for-each select="$subject/@* | $subject/node()">
            <xsl:copy>
                <xsl:call-template name="copy" />
            </xsl:copy>
        </xsl:for-each>
    </xsl:template>

    <xsl:function name="str:substring-after-last" as="xs:string">
        <xsl:param name="orig-string" as="xs:string?" />
        <xsl:param name="delimiter" as="xs:string" />
        <xsl:variable name="string" select="string($orig-string)" />
        <xsl:choose>
            <xsl:when test="contains($string, $delimiter)">
                <xsl:value-of select="str:substring-after-last(substring-after($string, $delimiter), $delimiter)" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$string" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>

    <xsl:function name="str:substring-before-first" as="xs:string">
        <xsl:param name="orig-string" as="xs:string?" />
        <xsl:param name="delimiter" as="xs:string" />
        <xsl:variable name="string" select="string($orig-string)" />
        <xsl:choose>
            <xsl:when test="contains($string, $delimiter)">
                <xsl:value-of select="str:substring-before-first(substring-before($string, $delimiter), $delimiter)" />
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$string" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>

    <xsl:function name="str:lang" as="xs:string">
        <xsl:param name="orig-lang" as="xs:string?" />
        <xsl:variable name="lang" select="document('eudml-lang.xml')/language-codes/language[code = lower-case($orig-lang)]" />
        <xsl:choose>
            <xsl:when test="$lang/code[@type = '639-1']"><xsl:value-of select="$lang/code[@type = '639-1']" /></xsl:when>
            <xsl:when test="$lang/code[@type = '639-2']"><xsl:value-of select="$lang/code[@type = '639-2']" /></xsl:when>
            <xsl:otherwise><xsl:value-of select="lower-case($orig-lang)" /></xsl:otherwise>
        </xsl:choose>
    </xsl:function>

</xsl:stylesheet>