<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:str="http://mathdoc.fr/string-function-namespace"
  xmlns:oai="http://www.openarchives.org/OAI/2.0/"
  xpath-default-namespace="http://yadda.icm.edu.pl/bwmeta-2.2.0.xsd"
  xmlns:xlink="http://www.w3.org/1999/xlink"
  xmlns="http://jats.nlm.nih.gov"
  xmlns:b="http://eudml.org/schema/2.0/eudml-book"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  exclude-result-prefixes="oai xlink str xsi b">
  
  <xsl:import href="eudml-utils.xsl"/>
    
  <xsl:param name="placeholderText" />

  <xsl:template match="//bwmeta/element">
    
    <xsl:variable name="lang" select="language[1]/@lang" />
    <b:book xsi:schemaLocation="http://eudml.org/schema/2.0/eudml-book http://eudml.org/schema/2.0/eudml-book-2.0.xsd"
            book-type="monograph">
      <xsl:if test="$lang != ''">
        <xsl:attribute name="xml:lang" select="str:lang($lang)" />
      </xsl:if>
      <b:front>
          <b:book-meta>
            <b:book-id pub-id-type="pldml-id">
              <xsl:value-of select="@id" />
            </b:book-id>
            <b:book-title-group>
              <xsl:choose>
                <xsl:when test="name[@lang = $lang]">
                  <xsl:apply-templates select="name[@lang = $lang]" />
                  <xsl:apply-templates select="name[@lang != $lang]" mode="trans" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="name[1]" />
                  <xsl:apply-templates select="name[not(1)]" mode="trans" />
                </xsl:otherwise>
              </xsl:choose>
            </b:book-title-group>
            <xsl:apply-templates select="structure/current/@position" />
            <xsl:apply-templates select="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Book_Series']/name" />
            <xsl:apply-templates select="id[@scheme = 'bwmeta1.id-class.ISSN']" />
            <xsl:if test="contributor[@role = 'author']">
              <contrib-group content-type="authors">
                <xsl:apply-templates select="contributor[@role = 'author']" />
              </contrib-group>
            </xsl:if>
            <xsl:apply-templates select="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Book_Publisher']/contributor[@role = 'publisher']" />
            
            <xsl:apply-templates select="id[@scheme = 'bwmeta1.id-class.ISBN']" />
            
            <xsl:apply-templates select="date[@type = 'published']" />
            
            <xsl:apply-templates select="contents/file[@format = 'application/pdf']" />
            
            <ext-link><xsl:value-of select="$placeholderText" /></ext-link>
              
            <xsl:apply-templates select="@id" mode="selfuri" />
            <xsl:apply-templates select="contents/file[@format = 'application/pdf']" mode="selfuri" />
            
            <xsl:apply-templates select="description[@lang = $lang][1]">
              <xsl:with-param name="lang" select="$lang" />
            </xsl:apply-templates>
            <xsl:apply-templates select="description[@lang != $lang]" mode="trans">
              <xsl:with-param name="lang" select="$lang" />
            </xsl:apply-templates>
            
            <xsl:apply-templates select="tags" />
    
            <custom-meta-group>
              <custom-meta>
                <meta-name>provider</meta-name>
                <meta-value>pldml</meta-value>
              </custom-meta>
            </custom-meta-group>
          </b:book-meta>
      </b:front>
    </b:book>
  </xsl:template>
  
  <xsl:template match="name">
    <b:book-title>
      <xsl:value-of select="." />
    </b:book-title>
  </xsl:template>
  
  <xsl:template match="name" mode="trans">
    <trans-title-group xml:lang="{str:lang(@lang)}">
      <trans-title>
        <xsl:value-of select="." />
      </trans-title>
    </trans-title-group>
  </xsl:template>
  
  <xsl:template match="structure/current/@position">
    <volume>
      <xsl:value-of select="." />
    </volume>
  </xsl:template>
  
  <xsl:template match="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Book_Series']/name">
    <series>
      <xsl:if test="@lang != ancestor::element/language[1]/@lang">
        <xsl:attribute name="xml:lang" select="str:lang(@lang)" />
      </xsl:if>
      <xsl:value-of select="." />
    </series>
  </xsl:template>
  
  <xsl:template match="id[@scheme = 'bwmeta1.id-class.ISSN']">
    <series content-type="issn">
      <xsl:value-of select="@value" />
    </series>
  </xsl:template>

  <xsl:template match="contributor[@role = 'author']">
    <contrib contrib-type="author">
      <xsl:choose>
        <xsl:when test="attribute[@key = 'person.firstname'] and attribute[@key = 'person.surname']">
          <name>
            <surname>
              <xsl:value-of select="attribute[@key = 'person.surname']/value" />
            </surname>
            <given-names>
              <xsl:value-of select="attribute[@key = 'person.firstname']/value" />
            </given-names>
          </name>
        </xsl:when>
        <xsl:otherwise>
          <string-name>
            <xsl:value-of select="normalize-space(name[@type = 'canonical'])" />
          </string-name>
        </xsl:otherwise>
      </xsl:choose>
    </contrib>
  </xsl:template>
  
  <xsl:template match="structure/ancestor[@level = 'bwmeta1.level.hierarchy_Book_Publisher']/contributor[@role = 'publisher']">
    <publisher>
      <xsl:apply-templates select="name" />
      <xsl:apply-templates select="ancestor::element/attribute[@key = 'publication.place']" />
    </publisher>
  </xsl:template>
  
  <xsl:template match="contributor[@role = 'publisher']/name">
    <publisher-name>
      <xsl:value-of select="normalize-space(.)" />
    </publisher-name>
  </xsl:template>
  
  <xsl:template match="attribute[@key = 'publication.place']">
    <publisher-loc>
      <xsl:value-of select="normalize-space(value)" />
    </publisher-loc>
  </xsl:template>
  
  <xsl:template match="id[@scheme = 'bwmeta1.id-class.ISBN']">
    <isbn>
      <xsl:value-of select="@value" />
    </isbn>
  </xsl:template>
  
  <xsl:template match="date[@type = 'published']">
    <pub-date>
      <year>
        <xsl:if test="@year">
          <xsl:value-of select="@year" />
        </xsl:if>
        <xsl:if test="not(@year)">
          <xsl:value-of select="." />
        </xsl:if>
      </year>
    </pub-date>
  </xsl:template>
  
  <xsl:template match="contents/file[@format = 'application/pdf']" mode="selfuri">
    <self-uri content-type="application/pdf" xlink:href="{location}">
      <xsl:text>Full (PDF)</xsl:text>
    </self-uri>
  </xsl:template>
  
  <xsl:template match="element/@id" mode="selfuri">
    <self-uri xlink:href="http://pldml.icm.edu.pl/pldml/element/{.}">
      <xsl:text>Access to full text</xsl:text>
    </self-uri>
  </xsl:template>
  
  <xsl:template match="description">
    <xsl:param name="lang" />
    <abstract>
      <p>
        <xsl:value-of select="." />
      </p>
      <xsl:for-each select="following-sibling::description[@lang = $lang]">
        <p>
          <xsl:value-of select="." />
        </p>
      </xsl:for-each>
    </abstract>
  </xsl:template>
  
  <xsl:template match="description" mode="trans">
    <xsl:param name="lang" />
    <trans-abstract xml:lang="{str:lang(@lang)}">
      <p>
        <xsl:value-of select="." />
      </p>
    </trans-abstract>
  </xsl:template>
  
  <xsl:template match="tags">
    <kwd-group>
      <xsl:if test="@lang != ancestor::element/language/@lang">
        <xsl:attribute name="xml:lang" select="str:lang(@lang)" />
      </xsl:if>
      <!-- <xsl:if test="@type != 'keyword'">
        <xsl:attribute name="kwd-group-type" select="@type" />
      </xsl:if> -->
      <xsl:apply-templates select="tag" />
    </kwd-group>
  </xsl:template>
  
  <xsl:template match="tag">
    <kwd>
      <xsl:value-of select="." />
    </kwd>
  </xsl:template>
  
  <xsl:template match="contents/file[@format = 'application/pdf']">
    <ext-link ext-link-type="eudml-fulltext:application/pdf" specific-use="index,enhance,serve" xlink:href="{location}">
      <xsl:text>MetaFull (PDF)</xsl:text>
    </ext-link>
  </xsl:template>
</xsl:stylesheet>